@@ -1,5 +1,5 @@
 /* This file is part of Metaproxy.
-   Copyright (C) 2005-2010 Index Data
+   Copyright (C) 2005-2012 Index Data
 
 Metaproxy is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -31,7 +31,8 @@ namespace metaproxy_1 {
         public:
             AuthSimple();
             ~AuthSimple();
-            void configure(const xmlNode * ptr, bool test_only);
+            void configure(const xmlNode * ptr, bool test_only,
+                           const char *path);
             void process(metaproxy_1::Package & package) const;
         private:
             void config_userRegister(std::string filename);
