@@ -425,12 +425,19 @@ yf::Z3950Client::Assoc *yf::Z3950Client::Rep::get_assoc(Package &package)
             mp::odr odr;
 
             package.response() = odr.create_initResponse(
-                apdu, YAZ_BIB1_TEMPORARY_SYSTEM_ERROR, "max sessions");
+                apdu, YAZ_BIB1_TEMPORARY_SYSTEM_ERROR,
+                "z3950_client: max sessions");
             package.session().close();
             return 0;
         }
         boost::xtime xt;
-        xtime_get(&xt, boost::TIME_UTC);
+        xtime_get(&xt,
+#if BOOST_VERSION >= 105000 
+                boost::TIME_UTC_
+#else
+                boost::TIME_UTC
+#endif 
+                );
 
         xt.sec += 15;
         if (!m_cond_session_ready.timed_wait(lock, xt))
@@ -438,7 +445,8 @@ yf::Z3950Client::Assoc *yf::Z3950Client::Rep::get_assoc(Package &package)
             mp::odr odr;
 
             package.response() = odr.create_initResponse(
-                apdu, YAZ_BIB1_TEMPORARY_SYSTEM_ERROR, "max sessions");
+                apdu, YAZ_BIB1_TEMPORARY_SYSTEM_ERROR,
+                "z3950_client: max sessions");
             package.session().close();
             return 0;
         }
